###############################################################################
# 3 plots which demonstrate our current understanding of air-sea gas transfer #
# velocity, based on field measurements. This code is released under a        #
# creative commonse CC-BY-SA (attribution, share-alike) license:              #
# http://creativecommons.org/licenses/by-sa/3.0/                              #
# plots generated from this code (modified or otherwise) are covered by a     #
# creative commons CC-BY (attribution) license:                               #
# http://creativecommons.org/licenses/by/3.0/                                 #
# to allow others to publish in licese-restrictive works                      #
#   please attribute as follows:                                              # 
# "(M.T.) Johnson, 2012, figshare.com/<link_to_file*>,                        #
# published under creative commons license."                                  #
# *insert link_to_file as appropriate                                         #
#                 any queries: martin_dot_johnson_at_uea_dot_ac_dot_uk,       #
#                 @martwine (twitter)                                         #
###############################################################################

# define a load of windspeeds against which to plot nice smooth curves!
WS_LOTS <- c(0.1,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30)


# load the T and S dependent transfer velocity / schmidt number / solubility scheme 
#see: 
# Johnson, 2010, A numerical scheme to calculate the temperature and salinity 
# dependent air-water transfer velocity for any gas, 
# Ocean Sci., 6, 913-932, 2010
# www.ocean-sci.net/6/913/2010/
# doi:10.5194/os-6-913-2010
# latest software version at github.com/martwine
source("K_calcs_Johnson_OS.R")
 #accompanying files needed:
 #  compounds.dat
 #  sw_constituent_mass_fractions.dat

# the above is used here for plotting different parameterisations, 
# including the solubility-dependent bubble scheme of Woolf (1997),
# (normalised to a given Schmidt number) for comparison with field data
# notice, it has been hacked to add some extra kw parameterisations and 
# also to set the default kw to be the Woolf bubble scheme for the total 
# transfer velocity in the third figure

#####################################################################
# load field data from files (listed below in read.table commands   #
# note: these have all been extracted from plots in the below cited #
# journal articles, using the g3data tool. As such (in spite of the #
# silly numbers of significnat figures generated by g3data), these  #
# values are rough approximations only - perfectly suitable for     #
# these plots, which are intended to summarise knowledge and data   #
# on the topic - but probably inappropriate for numerical analysis  #
# You have been warned!  MJ                                         #
#####################################################################

# Radon deficiency data from Bender et al., 2011
# Evaluating gas transfer velocity parameterizations using upper ocean 
# radon distributions, 
# JOURNAL OF GEOPHYSICAL RESEARCH, VOL. 116, C02010, 11 PP., 2011
# http://dx.doi.org/10.1029/2009JC005805
####################################################################################
Rn_bender_Atlantic_660<-read.table("Bender_radon_NSAtlantic.jpg.dat")
# convert this data from metres per day to cm per hour for comparison with other studies
# also scale to Sc_600 in line with dual tracer data
Rn_bender_atlantic_600_cmperhr<-Rn_bender_Atlantic_660[,2]*((600/660)^-0.5)*100/24
Rn_bender_600<-data.frame(Rn_bender_Atlantic_660[,1],Rn_bender_atlantic_600_cmperhr)

# the below data all taken from Ho et al., 2011 
# Toward a universal relationship between wind speed and gas
# exchange: Gas transfer velocities measured with 3He/SF6
# during the Southern Ocean Gas Exchange Experiment
# JOURNAL OF GEOPHYSICAL RESEARCH, VOL. 116, C00F04, doi:10.1029/2010JC006854, 2011
# http://dx.doi.org/10.1029/2010JC006854
# http://www.soest.hawaii.edu/~ho/papers/2010JC006854.pdf
#####################################################
DT_gasex98<-read.table("Ho_DT_Gasex98.dat")
DT_georgesbank<-read.table("Ho_DT_Georgesbank.dat")
DT_ironexII<-read.table("Ho_DT_IroneEXII.dat")
DT_NSea<-read.table("Ho_DT_NSEA.dat")
DT_SAGE<-read.table("Ho_DT_SAGE.dat")
DT_SOFEX<-read.table("Ho_DT_SOFEX.dat")
DT_SOGASEX<-read.table("Ho_DT_SOGASEX.dat")
DT_FSLE_ws<-4.3
DT_FSLE<-9.4
####################################################
# note these data are from previous studies, synthesised by 
# Ho et al., 2011 except SOGASEX



# EC CO2 data from Edson et al., 2011
# Direct covariance measurement of CO2 gas transfer velocity 
# during the 2008 Southern Ocean Gas Exchange Experiment: 
# Wind speed dependency
# JOURNAL OF GEOPHYSICAL RESEARCH, VOL. 116, C00F10, 24 PP., 2011
# http://www.agu.org/pubs/crossref/2011/2011JC007022.shtml
##############################################
ECCO2_gasex98<-read.table("EDSON_GASEX98.DAT")
ECCO2_SOGASEX<-read.table("EDSON_SOGASEX.dat")
##############################################
# again, a syntheses of past data
# note, GasEX 2001 experiment is also presented by Edson et al., 
# but not used here as few points at low winds don't add much and
# confuse the plots



# EC CO2 and DMS from Miller et al., 2009 (figure 3)
# Air-sea gas exchange of CO2 and DMS in the North Atlantic by eddy covariance
# GEOPHYSICAL RESEARCH LETTERS, VOL. 36, L15816, doi:10.1029/2009GL038907, 2009
# http://ess.uci.edu/researchgrp/esaltzman/files/2009gl038907.pdf
ECCO2_Knorr07<-read.table("Miller_knorr07CO2.dat")
ECDMS_Knorr07<-read.table("Miller_knorr07_DMS.dat")

# EC CO2 from Prytherch et al., 2010
# Open ocean gas transfer velocity derived from long-term 
# direct measurements of the CO2 flux
# GEOPHYSICAL RESEARCH LETTERS, VOL. 37, L23607, 5 PP., 2010
# http://dx.doi.org/10.1029/2010GL045597
ECCO2_HIWASE<-read.table("prytherchEC_Hiwase.dat")


#EC DMS data synthesised from mulitple campaigns by Yang et al., 2011
# Air‐sea exchange of dimethylsulfide in the Southern Ocean:
# Measurements from SO GasEx compared to temperate
# and tropical regions
#JOURNAL OF GEOPHYSICAL RESEARCH, VOL. 116, C00F05, doi:10.1029/2010JC006526, 2011
# ftp://ftp1.esrl.noaa.gov/users/cfairall/oceanobs/pubs/fy11/Yang%2520SO-GasEx%2520DMS%2520transfer-2011.pdf 
#############################################################
# binned summary of all data from figure 13
ECDMS_Yangsynthesis<-read.table("Yang_synthesis_DMSEC.dat")
# individual cruises binnd data (figure 11)
ECDMS_YangTAO<-read.table("Yang_DMS_TAO.dat")
ECDMS_YangDOGEE<-read.table("Yang_DMS_DOGEE.dat")
ECDMS_YangSOGASEX<-read.table("Yang_DMS_SO_GASEX.dat")
ECDMS_YangVOCALS<-read.table("Yang_DMS_VOCALS.dat")
ECDMS_YangBIO<-read.table("Yang_DMS_BIO.dat")
#############################################################


# EC DMS from Marandino et al., 2009
# Open ocean DMS air/sea fluxes over the eastern South Pacific Ocean
# Atmos. Chem. Phys., 9, 345–356, 2009
# http://www.atmos-chem-phys.net/9/345/2009/acp-9-345-2009.pdf
ECDMS_Knorr06<-read.table("marandinoECDMS_knor06.dat")
#convert from m/day to cm/her and to Sc_660
ECDMS_Knorr06_660<-cbind(ECDMS_Knorr06[,1],ECDMS_Knorr06[,2:4]*(100/24)*(660/720)^-0.5)


# define range of x and y axes
xrange<-c(0,20)
yrange<-c(0,100)

#some plotting variables
symbolcex<-1.8
plotlwd<-3
errorbarcol<-"gray40"



#global radiocarbon constraint from Naegler 2009: 
# Reconciliation of excess 14C-constrained global CO2 piston velocity estimates. 
# Tellus 61B, 372-384, doi: 10.1111/j.1600-0889.2008.00408.x.
# 16.5 +/- 3.2 cm/hr
# scale to short term/steady winds: multiply by 0.31/0.39 (Wanninkhof 1992 scaling [http://dx.doi.org/10.1029/92JC00188])
# then scale to Sc_600 from Sc_660: mulitply by (600/660)^-0.5
# estimate wind speed uncertainty 6.8-7.3
global_constraint_box<-c(6.8,(0.31/0.39)*(16.5-3.2),7.3,(0.31/0.39)*(16.5+3.2))
C14_bottom<-(0.31/0.39)*(16.5-3.2)*((600/660)^(-0.5))
C14_top<-(0.31/0.39)*(16.5+3.2)*((600/660)^(-0.5))


############################################################################################################################
############################################################################################################################
#
# First plot - summarising mass balance techniques and parameterisations                                                   #               
#
############################################################################################################################
############################################################################################################################

pdf("Mass_balance.pdf",width=12,height=8)


#par(mfrow=c(1,2), mar=c(6,6,2,2))	
par(mar=c(6,6,2,2))	
plot(xrange,yrange,type="n",
		xaxs="i", yaxs="i", lwd=2,tcl=0.5, cex.axis=1.3, cex.lab=1.8,
		xlab=expression(paste("wind speed / m.", s^{-1})),
		ylab=expression(paste(k[w_600]," / cm.", hr^{-1}))
	)
#'best fit' region from Ho et al 2011
polygon(x=c(WS_LOTS,rev(WS_LOTS)),y=c(Ho11kw_top("CO2",15,WS_LOTS,35,normalize=660)*360000,rev(Ho11kw_bottom("CO2",15,WS_LOTS,35,normalize=660)*360000)),border=NA,col="darkseagreen2")

# global 14C contraint area
rect(6.8,C14_bottom,7.3,C14_top,angle=-1,col="indianred2")

#plot relevant parameterisations
lines(WS_LOTS,Lissmerkw("CO2",15,WS_LOTS,35,normalize=600)*360000,col="gray30",lty="22",lwd=plotlwd)
lines(WS_LOTS,Nightingkw("CO2",15,WS_LOTS,35,normalize=600)*360000,lty="44",col="green4",lwd=plotlwd)
lines(WS_LOTS,Sweeneykw("CO2",15,WS_LOTS,35,normalize=600)*360000,lty="22",col="firebrick",lwd=plotlwd)
lines(WS_LOTS,Wannkw("CO2",15,WS_LOTS,35,normalize=600)*360000,lty="62",col="firebrick",lwd=plotlwd)
lines(WS_LOTS,WannMcGill99("CO2",15,WS_LOTS,35,normalize=600)*360000,lty="4212",col="firebrick",lwd=plotlwd)

# radon data
points(Rn_bender_600,pch=3,cex=1.6,col="dodgerblue3")


#DT data - error basrs (arrows) first
arrows(DT_georgesbank[,1],DT_georgesbank[,3],y1=DT_georgesbank[,4],angle=90,length=0.05,code=3,col=errorbarcol,lwd=1.6)
arrows(DT_FSLE_ws,DT_FSLE-0.75,y1=DT_FSLE+0.75,angle=90,length=0.05,code=3,col=errorbarcol,lwd=1.6)
arrows(DT_NSea[,1],DT_NSea[,3],y1=DT_NSea[,4],angle=90,length=0.05,code=3,col=errorbarcol,lwd=1.6)
arrows(DT_gasex98[,1],DT_gasex98[,3],y1=DT_gasex98[,4],angle=90,length=0.05,code=3,col=errorbarcol,lwd=1.6)
arrows(DT_ironexII[,1],DT_ironexII[,3],y1=DT_ironexII[,4],angle=90,length=0.05,code=3,col=errorbarcol,lwd=1.6)
arrows(DT_SAGE[,1],DT_SAGE[,3],y1=DT_SAGE[,4],angle=90,length=0.05,code=3,col=errorbarcol,lwd=1.6)
arrows(DT_SOFEX[,1],DT_SOFEX[,3],y1=DT_SOFEX[,4],angle=90,length=0.05,code=3,col=c(errorbarcol,"gray70",errorbarcol,"gray70"),lwd=1.6)
arrows(DT_SOGASEX[,1],DT_SOGASEX[,3],y1=DT_SOGASEX[,4],angle=90,length=0.05,code=3,col=errorbarcol,lwd=1.6)

# then symbols (points)
points(DT_georgesbank[,1],DT_georgesbank[,2],pch=24,cex=symbolcex,bg="white")
points(DT_FSLE_ws,DT_FSLE,pch=21,cex=symbolcex,col="black",bg="white")
points(DT_NSea[,1],DT_NSea[,2],pch=22,cex=symbolcex,col="black",bg="white")
points(DT_gasex98[,1],DT_gasex98[,2],pch=15,cex=symbolcex)
points(DT_ironexII[,1],DT_ironexII[,2],pch=25,cex=symbolcex,col="black",bg="black")
points(DT_SAGE[,1],DT_SAGE[,2],pch=16,cex=symbolcex,col="black",bg="white")
points(DT_SOFEX[,1],DT_SOFEX[,2],pch=17,cex=symbolcex,col=c("black","gray65","black","gray65"),bg=c("black","gray65","black","gray65"))
points(DT_SOGASEX[,1],DT_SOGASEX[,2],pch=23,cex=symbolcex,col="black",bg="black")

#hack to get the 14C rectangle style into the legend
rect(0.3,80.3,1.1,82.3,angle=-1,col="indianred2")

# then the legend
legend(0.3,100,
	c("Liss and Merlivat (1986)",
		"Nightingale et al (2000a)",
		"Sweeney et al (2007)",
		"Wanninkhof and McGillis (1999)",
		"Wanninkhof (1992)",
		"Global 14C constraint, Naegler(2009)",
		"Best fit to all dual tracer data, Ho et al (2011)",
		"DT, Southern Ocean, Ho et al (2011)",
		"DT, Southern Ocean, Ho et al (2006)",
		"DT, Southern Ocean, Wanninkhof et al (2004)",
		"DT, equatorial Pacific, Nightingale et al (2000b)",
		"DT, North Atlantic, McGillis et al (2001b)",
		"DT, North Sea, Nightingale et al (2000a)",
		"DT, Florida Shelf, Wanninkhof et al (1997)",
		"DT, Georges Bank, Asher and Wanninkhof (1998)",
		"Radon deficiency data, Bender et al (2011)"),
	lty=c("22","44","22","4212","62","solid","solid","blank","blank","blank","blank","blank","blank","blank","blank","blank"),
	pch=c(-1,-1,-1,-1,-1,-1,-1,23,16,17,25,15,22,21,24,3),
	lwd=c(plotlwd,plotlwd,plotlwd,plotlwd,plotlwd,0,15,-1,-1,-1,-1,-1,-1,-1,-1,-1),
	col=c("black","green4","firebrick","firebrick","firebrick","indianred2","darkseagreen2","black","black","black","black","black","black","black","black","dodgerblue3"),
	bty="n"	
)

dev.off()

############################################################################################################################
############################################################################################################################


# different y scale needed for Eddy Covariance measurements!!
yrange<-c(-10,240)

#some plot variables
CO2EBCol<-"gray70"
DMSEBCol<-"indianred2"


############################################################################################################################
############################################################################################################################
#
# Second plot summarising Eddy Covariance measurements, highlighting apparently greater kw for CO2 EC than dual tracer,    #
# but lower DMS. It's all about bubbles. Or surfactacts. Or airside control. Probably bubbles :-)                          #
#
############################################################################################################################
############################################################################################################################

pdf("Eddy_covariance.pdf",width=12,height=8)
#par(mfrow=c(1,2), mar=c(6,6,2,2))
par(mar=c(6,6,2,2))
#factor to upscale the DT data to Sc_660 (most of the EC data used is published at k_660)
sc660<-(660/600)^(-0.5)


#aggregate all the dual tracer data from previous figure as one dataframe and scale to Sc_660
DTdata<-rbind(DT_georgesbank,DT_FSLE,DT_NSea,DT_gasex98,DT_ironexII,DT_SAGE,DT_SOFEX,DT_SOGASEX)
DTdata$Sc660<-DTdata[,2]*sc660

#this plot defined as a function as had considered a detail vew ofthe first e.g. 12 m/s so could call twice
plotECdata<-function(xrange,yrange){
plot(xrange,yrange,type="n",
		xaxs="i", yaxs="i", lwd=2,tcl=0.5, cex.axis=1.3, cex.lab=1.8,
		xlab=expression(paste("wind speed / m.", s^{-1})),
		ylab=expression(paste(k[w_660]," / cm.", hr^{-1}))
	)

	# Ho et al best fit again
	polygon(x=c(WS_LOTS,rev(WS_LOTS)),y=c(Ho11kw_top("CO2",15,WS_LOTS,35,normalize=660)*360000,rev(Ho11kw_bottom("CO2",15,WS_LOTS,35,normalize=660)*360000)),border=NA,col="darkseagreen2")	

	# relevant parameterisations
	lines(WS_LOTS,Lissmerkw("CO2",15,WS_LOTS,35,normalize=660)*360000,col="gray30",lty="22",lwd=plotlwd/2)
	lines(WS_LOTS,prytherchkw("CO2",15,WS_LOTS,35,normalize=660)*360000,lty="4212",col="midnightblue",lwd=plotlwd/1.6)
	lines(WS_LOTS,McGilliskw("CO2",15,WS_LOTS,35,normalize=600)*360000,lty="62",col="midnightblue",lwd=plotlwd/1.6)
	lines(WS_LOTS,edsonkw("CO2",15,WS_LOTS,35,normalize=600)*360000,lty="44",col="midnightblue",lwd=plotlwd/1.6)

	# dual tracer data
	points(DTdata[,1],DTdata$Sc660,pch=17,cex=symbolcex/1.8,col="palegreen4",bg="darkseagreen2")
	
	
	
	arrows(ECCO2_gasex98[,1],ECCO2_gasex98[,3],y1=ECCO2_gasex98[,4],angle=90,length=0.05,code=3,col=CO2EBCol,lwd=1.6)
	arrows(ECCO2_SOGASEX[,1],ECCO2_SOGASEX[,3],y1=ECCO2_SOGASEX[,4],angle=90,length=0.05,code=3,col=CO2EBCol,lwd=1.6)
	arrows(ECCO2_Knorr07[,1],ECCO2_Knorr07[,3],y1=ECCO2_Knorr07[,4],angle=90,length=0.05,code=3,col=CO2EBCol,lwd=1.6)
	arrows(ECCO2_HIWASE[,1],ECCO2_HIWASE[,3],y1=ECCO2_HIWASE[,4],angle=90,length=0.05,code=3,col=CO2EBCol,lwd=1.6)

	# Yang synthesis error bars too small to bother with
	#arrows(ECDMS_Yangsynthesis[,1],ECDMS_Yangsynthesis[,3],y1=ECDMS_Yangsynthesis[,4],angle=90,length=0.05,code=3,col=DMSEBCol,lwd=1.6)
	arrows(ECDMS_Knorr07[,1],ECDMS_Knorr07[,3],y1=ECDMS_Knorr07[,4],angle=90,length=0.05,code=3,col=DMSEBCol,lwd=1.6)
	arrows(ECDMS_Knorr06_660[,1],ECDMS_Knorr06_660[,3],y1=ECDMS_Knorr06_660[,4],angle=90,length=0.05,code=3,col=DMSEBCol,lwd=1.6)
	points(ECCO2_gasex98[,1],ECCO2_gasex98[,2],pch=22,cex=symbolcex/1.2,col="black",bg="white",lwd=1.5)
	points(ECCO2_SOGASEX[,1],ECCO2_SOGASEX[,2],pch=22,cex=symbolcex/1.2,col="black",bg="gray80",lwd=1.5)
	points(ECCO2_Knorr07[,1],ECCO2_Knorr07[,2],pch=22,cex=symbolcex/1.2,col="black",bg="gray60",lwd=1.5)
	points(ECCO2_HIWASE[,1],ECCO2_HIWASE[,2],pch=22,cex=symbolcex/1.2,col="gray80",bg="gray40",lwd=1.5)

	# lump all the cruises shown in the Yang paper into one to keep plot simple
	ECDMS_Yangall<-rbind(ECDMS_YangTAO,ECDMS_YangBIO,ECDMS_YangVOCALS,ECDMS_YangDOGEE,ECDMS_YangSOGASEX)

	points(ECDMS_Yangall[,1],ECDMS_Yangall[,2],pch=21,cex=symbolcex/1.2,col="black",bg="indianred2",lwd=1.5)
	# alternatively, can plot the sytheses/ averaging of all the raw data into 8 windspeed binned averages follwing Yang et al 2011	
	# points(ECDMS_Yangsynthesis[,1],ECDMS_Yangsynthesis[,2],pch=21,cex=symbolcex/1.2,col="black",bg="indianred2",lwd=1.5)
	points(ECDMS_Knorr07[,1],ECDMS_Knorr07[,2],pch=21,cex=symbolcex/1.2,col="black",bg="pink3",lwd=1.5)
	points(ECDMS_Knorr06_660[,1],ECDMS_Knorr06_660[,2],pch=21,cex=symbolcex/1.2,col="indianred3",bg="white",lwd=1.5)

}


# call the function with the x and y ranges of your choice!
#plotECdata(c(0,16),c(-10,120))
plotECdata(c(0,20),c(-10,250))
legend(0.3,250,
	c("Liss and Merlivat (1986)",
		"McGillis et al 2001",
		"Prytherch et al 2010a",
		"Edsonn et al 2011",
		"Best fit to all dual tracer data, Ho et al (2011)",
		"All dual tracer data",
		"EC CO2, GasEX98, Edson et al 2011",
		"EC CO2, SOGasEX, Edson et al 2011",
		"EC CO2, Knorr07, Miller et al 2009",
		"EC CO2, HIWASE, Prytherch et al 2010a",
		"EC DMS, multiple campaigns, Yang et al 2011",
		"EC DMS, Knorr07, Miller et al 2009",
		"EC DMS, Knorr06, Marandino et al 2009"),
	lty=c("22","4212","62","44","solid","blank","blank","blank","blank","blank","blank","blank","blank"),
	pch=c(-1,-1,-1,-1,-1,17,22,22,22,22,21,21,21),
	lwd=c(plotlwd/2,plotlwd/1.6,plotlwd/1.6,plotlwd/1.6,15,-1,-1,-1,-1,-1,-1,-1,-1),
	col=c("black","midnightblue","midnightblue","midnightblue","darkseagreen2","palegreen4","black","black","black","gray80","black","black","indianred3"),
	pt.bg=c("white","white","white","white","white","white","white","gray80","gray60","gray40","indianred2","pink3","white"),
	bty="n"	
)

dev.off()


############################################################################################################################
############################################################################################################################






############################################################################################################################
############################################################################################################################
# finally a plot summarising the EC CO2 and DMS data, highlighting the bubble-bases explanation using Johnson scheme to
# demonstrate the Woolf (1997) bubble model (as used by NOAA COARE)
############################################################################################################################
############################################################################################################################

#lump all the EC data into one set of CO2 and one of DMS (with some hacking of column names)
ECCO2<-rbind(ECCO2_gasex98,ECCO2_SOGASEX,ECCO2_Knorr07,ECCO2_HIWASE)
colnames(ECDMS_Knorr06_660)<-c("V1","V2","V3","V4")
ECDMS<-rbind(ECDMS_Yangsynthesis,ECDMS_Knorr07,ECDMS_Knorr06_660)


pdf("EC_bubbles.pdf",width=8,height=8)
	par(mar=c(6,6,2,2))
plot(xrange,c(0,160),type="n",
		xaxs="i", axes=FALSE, yaxs="i", lwd=2,tcl=0.5, cex.axis=1.3, cex.lab=1.8,
		xlab=expression(paste("wind speed / m.", s^{-1})),
		ylab=expression(paste(k[w_660]," / cm.", hr^{-1}))
	)

	#Show area under CO2 curve as predicted by Woolf Model - diffusive plus bubble transport
	polygon(c(WS_LOTS,max(WS_LOTS),0),c(Woolf97kw("CO2",15,WS_LOTS,35,normalize=660)*360000,0,0),border=NA,col="gray80")
	# show area under DMS curve in pink. Bubble effect is tiny, so effectively just the diffusive part, 
        # the remaining grey bit being the magnitude of the bubble effect for CO2
	polygon(c(WS_LOTS,max(WS_LOTS),0),c(Woolf97kw("DMS",15,WS_LOTS,35,normalize=660)*360000,0,0),border=NA,col="lightpink1")

	#points(DTdata[,1],DTdata$Sc660,pch=17,cex=symbolcex/1.8,col="palegreen4",bg="darkseagreen2")
	#plot the 2 aggregated EC datsets
	points(ECCO2[,1],ECCO2[,2],pch=22,col="gray40",bg="gray66")
	points(ECDMS[,1],ECDMS[,2],pch=21,col="gray40",bg="indianred3")

	#add in the Woolf Model predictions for CO2 and DMS (delineating the areas drawn) 
	lines(WS_LOTS,Woolf97kw("CO2",15,WS_LOTS,35,normalize=660)*360000,col="gray20",lwd=plotlwd)
	lines(WS_LOTS,Woolf97kw("DMS",15,WS_LOTS,35,normalize=660)*360000,col="indianred4",lwd=plotlwd)

	# the DMS transfer velocity is sensitive to the air-side resistance to transfer
	lines(WS_LOTS,Kw("DMS",15,WS_LOTS,35)*360000,lty=2,col="indianred4",lwd=plotlwd/2)
	

	
	legend(0.5,160,
		c(	"EC CO2 data",
			"EC DMS data",
			"bubble k(CO2_660), Woolf 1997",
			"bubble k(DMS_660), Woolf 1997",
			"Kw_DMS, Woolf 1997, Johnson 2010"),
		lty=c(-1,-1,1,1,2),
		lwd=c(-1,-1,plotlwd,plotlwd,plotlwd/2),
		pch=c(22,21,-1,-1,-1),
		col=c("gray40","gray40","gray20","indianred4","indianred4"),
		pt.bg=c("gray66","indianred3","white","white","white"),
		bty="n"
	)
	

	axis(1,cex.axis=1.3,tcl=0.5)
	axis(2,cex.axis=1.3,tcl=0.5,at=c(0,40,80,120,160))
	axis(3,lwd.ticks=-1,labels=FALSE)
	axis(4,lwd.ticks=-1,labels=FALSE,at=c(0,160))

dev.off()
	
